"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.events.events_manager_pb2

class EventsManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetEvents: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.events.events_manager_pb2.GetEventsReq,
        prodvana.proto.prodvana.events.events_manager_pb2.GetEventsResp,
    ]

class EventsManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetEvents(
        self,
        request: prodvana.proto.prodvana.events.events_manager_pb2.GetEventsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.events.events_manager_pb2.GetEventsResp: ...

def add_EventsManagerServicer_to_server(servicer: EventsManagerServicer, server: grpc.Server) -> None: ...
