"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.links_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ServiceUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    FOLLOW_REPOSITORY_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.links_pb2.Link]: ...
    @property
    def follow_repository(self) -> global___FollowContainerRepositorySettings: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        links: collections.abc.Iterable[prodvana.proto.prodvana.common_config.links_pb2.Link] | None = ...,
        follow_repository: global___FollowContainerRepositorySettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["follow_repository", b"follow_repository"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "follow_repository", b"follow_repository", "links", b"links"]) -> None: ...

global___ServiceUserMetadata = ServiceUserMetadata

class FollowContainerRepositorySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___FollowContainerRepositorySettings = FollowContainerRepositorySettings
