# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.delivery_extension import manager_pb2 as prodvana_dot_delivery__extension_dot_manager__pb2


class DeliveryExtensionManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigureDeliveryExtension = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/ConfigureDeliveryExtension',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionResp.FromString,
                )
        self.ValidateConfigureDeliveryExtension = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/ValidateConfigureDeliveryExtension',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ValidateConfigureDeliveryExtensionResp.FromString,
                )
        self.ListDeliveryExtensions = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/ListDeliveryExtensions',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsResp.FromString,
                )
        self.GetDeliveryExtension = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtension',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionResp.FromString,
                )
        self.GetDeliveryExtensionConfig = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtensionConfig',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigResp.FromString,
                )
        self.GetDeliveryExtensionInstanceConfig = channel.unary_unary(
                '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtensionInstanceConfig',
                request_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigResp.FromString,
                )


class DeliveryExtensionManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigureDeliveryExtension(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateConfigureDeliveryExtension(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeliveryExtensions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryExtension(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryExtensionConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryExtensionInstanceConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeliveryExtensionManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigureDeliveryExtension': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureDeliveryExtension,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionResp.SerializeToString,
            ),
            'ValidateConfigureDeliveryExtension': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateConfigureDeliveryExtension,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ValidateConfigureDeliveryExtensionResp.SerializeToString,
            ),
            'ListDeliveryExtensions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeliveryExtensions,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsResp.SerializeToString,
            ),
            'GetDeliveryExtension': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryExtension,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionResp.SerializeToString,
            ),
            'GetDeliveryExtensionConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryExtensionConfig,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigResp.SerializeToString,
            ),
            'GetDeliveryExtensionInstanceConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryExtensionInstanceConfig,
                    request_deserializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigReq.FromString,
                    response_serializer=prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.delivery_extension.DeliveryExtensionManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeliveryExtensionManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigureDeliveryExtension(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/ConfigureDeliveryExtension',
            prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateConfigureDeliveryExtension(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/ValidateConfigureDeliveryExtension',
            prodvana_dot_delivery__extension_dot_manager__pb2.ConfigureDeliveryExtensionReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.ValidateConfigureDeliveryExtensionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeliveryExtensions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/ListDeliveryExtensions',
            prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.ListDeliveryExtensionsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryExtension(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtension',
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryExtensionConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtensionConfig',
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryExtensionInstanceConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_extension.DeliveryExtensionManager/GetDeliveryExtensionInstanceConfig',
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigReq.SerializeToString,
            prodvana_dot_delivery__extension_dot_manager__pb2.GetDeliveryExtensionInstanceConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
