"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ObjectType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ObjectTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ObjectType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _ObjectType.ValueType  # 0
    RUNTIME: _ObjectType.ValueType  # 1
    APPLICATION: _ObjectType.ValueType  # 2
    SERVICE: _ObjectType.ValueType  # 3
    RELEASE_CHANNEL: _ObjectType.ValueType  # 4
    PROTECTION: _ObjectType.ValueType  # 5
    RELEASE: _ObjectType.ValueType  # 6

class ObjectType(_ObjectType, metaclass=_ObjectTypeEnumTypeWrapper): ...

UNKNOWN: ObjectType.ValueType  # 0
RUNTIME: ObjectType.ValueType  # 1
APPLICATION: ObjectType.ValueType  # 2
SERVICE: ObjectType.ValueType  # 3
RELEASE_CHANNEL: ObjectType.ValueType  # 4
PROTECTION: ObjectType.ValueType  # 5
RELEASE: ObjectType.ValueType  # 6
global___ObjectType = ObjectType

class ObjectMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CONFIG_VERSION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    version: builtins.str
    config_version: builtins.str
    """only set for objects who has configurations with parametrization support. At the time of this writing, only services."""
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    type: global___ObjectType.ValueType
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        version: builtins.str = ...,
        config_version: builtins.str = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        type: global___ObjectType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_version", b"config_version", "id", b"id", "name", b"name", "source", b"source", "source_metadata", b"source_metadata", "type", b"type", "version", b"version"]) -> None: ...

global___ObjectMeta = ObjectMeta
