"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    API_USER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FIRST_NAME_FIELD_NUMBER: builtins.int
    LAST_NAME_FIELD_NUMBER: builtins.int
    EMAILS_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    api_user: builtins.bool
    """indicates if this user represents an api token"""
    name: builtins.str
    """user info, all optional"""
    first_name: builtins.str
    last_name: builtins.str
    @property
    def emails(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        api_user: builtins.bool = ...,
        name: builtins.str = ...,
        first_name: builtins.str = ...,
        last_name: builtins.str = ...,
        emails: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_user", b"api_user", "emails", b"emails", "first_name", b"first_name", "last_name", b"last_name", "name", b"name", "user_id", b"user_id"]) -> None: ...

global___User = User
