# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/secrets/secrets_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/secrets/secrets_manager.proto\x12\x14prodvana.environment\x1a\x1cgoogle/api/annotations.proto\x1a prodvana/common_config/env.proto\x1a\x17validate/validate.proto\"\x10\n\x0eListSecretsReq\"B\n\x0fListSecretsResp\x12/\n\x07secrets\x18\x01 \x03(\x0b\x32\x1e.prodvana.common_config.Secret\"-\n\x15ListSecretVersionsReq\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"*\n\x16ListSecretVersionsResp\x12\x10\n\x08versions\x18\x01 \x03(\t\"<\n\x0cSetSecretReq\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05value\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\" \n\rSetSecretResp\x12\x0f\n\x07version\x18\x01 \x01(\t\"\'\n\x0f\x44\x65leteSecretReq\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x12\n\x10\x44\x65leteSecretResp\"H\n\x16\x44\x65leteSecretVersionReq\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07version\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x19\n\x17\x44\x65leteSecretVersionResp2\xbe\x05\n\x0eSecretsManager\x12t\n\x0bListSecrets\x12$.prodvana.environment.ListSecretsReq\x1a%.prodvana.environment.ListSecretsResp\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/secrets/list\x12\x95\x01\n\x12ListSecretVersions\x12+.prodvana.environment.ListSecretVersionsReq\x1a,.prodvana.environment.ListSecretVersionsResp\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/secrets/{key=*}/versions\x12l\n\tSetSecret\x12\".prodvana.environment.SetSecretReq\x1a#.prodvana.environment.SetSecretResp\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/secrets:\x01*\x12\x81\x01\n\x0c\x44\x65leteSecret\x12%.prodvana.environment.DeleteSecretReq\x1a&.prodvana.environment.DeleteSecretResp\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/secrets/{key=*}/delete\x12\xab\x01\n\x13\x44\x65leteSecretVersion\x12,.prodvana.environment.DeleteSecretVersionReq\x1a-.prodvana.environment.DeleteSecretVersionResp\"7\x82\xd3\xe4\x93\x02\x31*//v1/secrets/{key=*}/versions/{version=*}/deleteBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/secretsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.secrets.secrets_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/secrets'
  _LISTSECRETVERSIONSREQ.fields_by_name['key']._options = None
  _LISTSECRETVERSIONSREQ.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _SETSECRETREQ.fields_by_name['key']._options = None
  _SETSECRETREQ.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _SETSECRETREQ.fields_by_name['value']._options = None
  _SETSECRETREQ.fields_by_name['value']._serialized_options = b'\372B\004r\002\020\001'
  _DELETESECRETREQ.fields_by_name['key']._options = None
  _DELETESECRETREQ.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _DELETESECRETVERSIONREQ.fields_by_name['key']._options = None
  _DELETESECRETVERSIONREQ.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _DELETESECRETVERSIONREQ.fields_by_name['version']._options = None
  _DELETESECRETVERSIONREQ.fields_by_name['version']._serialized_options = b'\372B\004r\002\020\001'
  _SECRETSMANAGER.methods_by_name['ListSecrets']._options = None
  _SECRETSMANAGER.methods_by_name['ListSecrets']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/secrets/list'
  _SECRETSMANAGER.methods_by_name['ListSecretVersions']._options = None
  _SECRETSMANAGER.methods_by_name['ListSecretVersions']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/secrets/{key=*}/versions'
  _SECRETSMANAGER.methods_by_name['SetSecret']._options = None
  _SECRETSMANAGER.methods_by_name['SetSecret']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/secrets:\001*'
  _SECRETSMANAGER.methods_by_name['DeleteSecret']._options = None
  _SECRETSMANAGER.methods_by_name['DeleteSecret']._serialized_options = b'\202\323\344\223\002\034*\032/v1/secrets/{key=*}/delete'
  _SECRETSMANAGER.methods_by_name['DeleteSecretVersion']._options = None
  _SECRETSMANAGER.methods_by_name['DeleteSecretVersion']._serialized_options = b'\202\323\344\223\0021*//v1/secrets/{key=*}/versions/{version=*}/delete'
  _globals['_LISTSECRETSREQ']._serialized_start=153
  _globals['_LISTSECRETSREQ']._serialized_end=169
  _globals['_LISTSECRETSRESP']._serialized_start=171
  _globals['_LISTSECRETSRESP']._serialized_end=237
  _globals['_LISTSECRETVERSIONSREQ']._serialized_start=239
  _globals['_LISTSECRETVERSIONSREQ']._serialized_end=284
  _globals['_LISTSECRETVERSIONSRESP']._serialized_start=286
  _globals['_LISTSECRETVERSIONSRESP']._serialized_end=328
  _globals['_SETSECRETREQ']._serialized_start=330
  _globals['_SETSECRETREQ']._serialized_end=390
  _globals['_SETSECRETRESP']._serialized_start=392
  _globals['_SETSECRETRESP']._serialized_end=424
  _globals['_DELETESECRETREQ']._serialized_start=426
  _globals['_DELETESECRETREQ']._serialized_end=465
  _globals['_DELETESECRETRESP']._serialized_start=467
  _globals['_DELETESECRETRESP']._serialized_end=485
  _globals['_DELETESECRETVERSIONREQ']._serialized_start=487
  _globals['_DELETESECRETVERSIONREQ']._serialized_end=559
  _globals['_DELETESECRETVERSIONRESP']._serialized_start=561
  _globals['_DELETESECRETVERSIONRESP']._serialized_end=586
  _globals['_SECRETSMANAGER']._serialized_start=589
  _globals['_SECRETSMANAGER']._serialized_end=1291
# @@protoc_insertion_point(module_scope)
