"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EfficiencyStat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAVED_LINES_FIELD_NUMBER: builtins.int
    MATERIALIZED_LINES_FIELD_NUMBER: builtins.int
    saved_lines: builtins.int
    """how many lines did Prodvana save you from writing? Computed by comparing materialized yaml to proto text format"""
    materialized_lines: builtins.int
    """how many lines of materialized config was either added, modified, or deleted?"""
    def __init__(
        self,
        *,
        saved_lines: builtins.int = ...,
        materialized_lines: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["materialized_lines", b"materialized_lines", "saved_lines", b"saved_lines"]) -> None: ...

global___EfficiencyStat = EfficiencyStat
