# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.release import object_pb2 as prodvana_dot_release_dot_object__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/release/manager.proto\x12\x10prodvana.release\x1a\x1cgoogle/api/annotations.proto\x1a\x1aprodvana/object/meta.proto\x1a\x1dprodvana/release/object.proto\x1a\x17validate/validate.proto\"^\n\x10RecordReleaseReq\x12\x39\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.release.ReleaseConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0f\n\x07pending\x18\x02 \x01(\x08\">\n\x11RecordReleaseResp\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\"]\n\x16UpdateReleaseStatusReq\x12\x12\n\nrelease_id\x18\x01 \x01(\t\x12/\n\x06status\x18\x02 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\"J\n\x17UpdateReleaseStatusResp\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\"j\n\rReleaseFilter\x12\x10\n\x08services\x18\x01 \x03(\t\x12\x18\n\x10release_channels\x18\x02 \x03(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\"\xd3\x01\n\x0fListReleasesReq\x12\x30\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x1f.prodvana.release.ReleaseFilter\x12/\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1f.prodvana.release.ReleaseFilter\x12\x1b\n\x13starting_release_id\x18\x03 \x01(\t\x12\x19\n\x11\x65nding_release_id\x18\x04 \x01(\t\x12\x12\n\npage_token\x18\x05 \x01(\t\x12\x11\n\tpage_size\x18\x06 \x01(\x05\"X\n\x10ListReleasesResp\x12+\n\x08releases\x18\x01 \x03(\x0b\x32\x19.prodvana.release.Release\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"a\n\nReleaseRef\x12\x14\n\nrelease_id\x18\x01 \x01(\tH\x00\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1f.prodvana.release.ReleaseConfigH\x00\x42\n\n\x03ref\x12\x03\xf8\x42\x01\"\x84\x01\n\x11\x43ompareReleaseReq\x12;\n\x0bnew_release\x18\x01 \x01(\x0b\x32\x1c.prodvana.release.ReleaseRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x32\n\x0cprev_release\x18\x02 \x01(\x0b\x32\x1c.prodvana.release.ReleaseRef\"M\n\x12\x43ompareReleaseResp\x12\x37\n\ncomparison\x18\x01 \x01(\x0b\x32#.prodvana.release.ReleaseComparison\"\x82\x01\n\x11PreviewReleaseReq\x12\x39\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.release.ReleaseConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x32\n\x0cprev_release\x18\x02 \x01(\x0b\x32\x1c.prodvana.release.ReleaseRef\"@\n\x12PreviewReleaseResp\x12*\n\x07release\x18\x01 \x01(\x0b\x32\x19.prodvana.release.Release\"\xd1\x01\n\x14GetLatestReleasesReq\x12\x30\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x1f.prodvana.release.ReleaseFilter\x12/\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1f.prodvana.release.ReleaseFilter\x12/\n\x06status\x18\x03 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"]\n\x15GetLatestReleasesResp\x12+\n\x08releases\x18\x01 \x03(\x0b\x32\x19.prodvana.release.Release\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"r\n\x16ReleaseServiceInstance\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xdc\x01\n\x17\x43heckCommitInReleaseReq\x12\x1d\n\nrelease_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12V\n\x18release_service_instance\x18\x02 \x01(\x0b\x32(.prodvana.release.ReleaseServiceInstanceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x1b\n\nrepository\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06\x63ommit\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x14\n\rrelease_oneof\x12\x03\xf8\x42\x01\"\xa5\x01\n\x18\x43heckCommitInReleaseResp\x12\x41\n\x06result\x18\x01 \x01(\x0e\x32\x31.prodvana.release.CheckCommitInReleaseResp.Result\"F\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08INCLUDED\x10\x01\x12\x0f\n\x0bNO_RELATION\x10\x02\x12\x10\n\x0cNOT_INCLUDED\x10\x03\x32\x80\x08\n\x0eReleaseManager\x12q\n\rRecordRelease\x12\".prodvana.release.RecordReleaseReq\x1a#.prodvana.release.RecordReleaseResp\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/releases:\x01*\x12\x99\x01\n\x13UpdateReleaseStatus\x12(.prodvana.release.UpdateReleaseStatusReq\x1a).prodvana.release.UpdateReleaseStatusResp\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/releases/{release_id=*}/status:\x01*\x12k\n\x0cListReleases\x12!.prodvana.release.ListReleasesReq\x1a\".prodvana.release.ListReleasesResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/releases\x12_\n\x12ListReleasesStream\x12!.prodvana.release.ListReleasesReq\x1a\".prodvana.release.ListReleasesResp\"\x00\x30\x01\x12|\n\x0e\x43ompareRelease\x12#.prodvana.release.CompareReleaseReq\x1a$.prodvana.release.CompareReleaseResp\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/releases/compare:\x01*\x12|\n\x0ePreviewRelease\x12#.prodvana.release.PreviewReleaseReq\x1a$.prodvana.release.PreviewReleaseResp\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/releases/preview:\x01*\x12\x81\x01\n\x11GetLatestReleases\x12&.prodvana.release.GetLatestReleasesReq\x1a\'.prodvana.release.GetLatestReleasesResp\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/releases/latest\x12\x90\x01\n\x14\x43heckCommitInRelease\x12).prodvana.release.CheckCommitInReleaseReq\x1a*.prodvana.release.CheckCommitInReleaseResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/releases/check_commitBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/releaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release'
  _RECORDRELEASEREQ.fields_by_name['config']._options = None
  _RECORDRELEASEREQ.fields_by_name['config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RELEASEREF.oneofs_by_name['ref']._options = None
  _RELEASEREF.oneofs_by_name['ref']._serialized_options = b'\370B\001'
  _COMPARERELEASEREQ.fields_by_name['new_release']._options = None
  _COMPARERELEASEREQ.fields_by_name['new_release']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PREVIEWRELEASEREQ.fields_by_name['config']._options = None
  _PREVIEWRELEASEREQ.fields_by_name['config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RELEASESERVICEINSTANCE.fields_by_name['application']._options = None
  _RELEASESERVICEINSTANCE.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASESERVICEINSTANCE.fields_by_name['service']._options = None
  _RELEASESERVICEINSTANCE.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASESERVICEINSTANCE.fields_by_name['release_channel']._options = None
  _RELEASESERVICEINSTANCE.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _CHECKCOMMITINRELEASEREQ.oneofs_by_name['release_oneof']._options = None
  _CHECKCOMMITINRELEASEREQ.oneofs_by_name['release_oneof']._serialized_options = b'\370B\001'
  _CHECKCOMMITINRELEASEREQ.fields_by_name['release_id']._options = None
  _CHECKCOMMITINRELEASEREQ.fields_by_name['release_id']._serialized_options = b'\372B\004r\002\020\001'
  _CHECKCOMMITINRELEASEREQ.fields_by_name['release_service_instance']._options = None
  _CHECKCOMMITINRELEASEREQ.fields_by_name['release_service_instance']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CHECKCOMMITINRELEASEREQ.fields_by_name['repository']._options = None
  _CHECKCOMMITINRELEASEREQ.fields_by_name['repository']._serialized_options = b'\372B\004r\002\020\001'
  _CHECKCOMMITINRELEASEREQ.fields_by_name['commit']._options = None
  _CHECKCOMMITINRELEASEREQ.fields_by_name['commit']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASEMANAGER.methods_by_name['RecordRelease']._options = None
  _RELEASEMANAGER.methods_by_name['RecordRelease']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/releases:\001*'
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._options = None
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._serialized_options = b'\202\323\344\223\002\'\"\"/v1/releases/{release_id=*}/status:\001*'
  _RELEASEMANAGER.methods_by_name['ListReleases']._options = None
  _RELEASEMANAGER.methods_by_name['ListReleases']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/releases'
  _RELEASEMANAGER.methods_by_name['CompareRelease']._options = None
  _RELEASEMANAGER.methods_by_name['CompareRelease']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/releases/compare:\001*'
  _RELEASEMANAGER.methods_by_name['PreviewRelease']._options = None
  _RELEASEMANAGER.methods_by_name['PreviewRelease']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/releases/preview:\001*'
  _RELEASEMANAGER.methods_by_name['GetLatestReleases']._options = None
  _RELEASEMANAGER.methods_by_name['GetLatestReleases']._serialized_options = b'\202\323\344\223\002\025\022\023/v1/releases/latest'
  _RELEASEMANAGER.methods_by_name['CheckCommitInRelease']._options = None
  _RELEASEMANAGER.methods_by_name['CheckCommitInRelease']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/releases/check_commit'
  _globals['_RECORDRELEASEREQ']._serialized_start=166
  _globals['_RECORDRELEASEREQ']._serialized_end=260
  _globals['_RECORDRELEASERESP']._serialized_start=262
  _globals['_RECORDRELEASERESP']._serialized_end=324
  _globals['_UPDATERELEASESTATUSREQ']._serialized_start=326
  _globals['_UPDATERELEASESTATUSREQ']._serialized_end=419
  _globals['_UPDATERELEASESTATUSRESP']._serialized_start=421
  _globals['_UPDATERELEASESTATUSRESP']._serialized_end=495
  _globals['_RELEASEFILTER']._serialized_start=497
  _globals['_RELEASEFILTER']._serialized_end=603
  _globals['_LISTRELEASESREQ']._serialized_start=606
  _globals['_LISTRELEASESREQ']._serialized_end=817
  _globals['_LISTRELEASESRESP']._serialized_start=819
  _globals['_LISTRELEASESRESP']._serialized_end=907
  _globals['_RELEASEREF']._serialized_start=909
  _globals['_RELEASEREF']._serialized_end=1006
  _globals['_COMPARERELEASEREQ']._serialized_start=1009
  _globals['_COMPARERELEASEREQ']._serialized_end=1141
  _globals['_COMPARERELEASERESP']._serialized_start=1143
  _globals['_COMPARERELEASERESP']._serialized_end=1220
  _globals['_PREVIEWRELEASEREQ']._serialized_start=1223
  _globals['_PREVIEWRELEASEREQ']._serialized_end=1353
  _globals['_PREVIEWRELEASERESP']._serialized_start=1355
  _globals['_PREVIEWRELEASERESP']._serialized_end=1419
  _globals['_GETLATESTRELEASESREQ']._serialized_start=1422
  _globals['_GETLATESTRELEASESREQ']._serialized_end=1631
  _globals['_GETLATESTRELEASESRESP']._serialized_start=1633
  _globals['_GETLATESTRELEASESRESP']._serialized_end=1726
  _globals['_RELEASESERVICEINSTANCE']._serialized_start=1728
  _globals['_RELEASESERVICEINSTANCE']._serialized_end=1842
  _globals['_CHECKCOMMITINRELEASEREQ']._serialized_start=1845
  _globals['_CHECKCOMMITINRELEASEREQ']._serialized_end=2065
  _globals['_CHECKCOMMITINRELEASERESP']._serialized_start=2068
  _globals['_CHECKCOMMITINRELEASERESP']._serialized_end=2233
  _globals['_CHECKCOMMITINRELEASERESP_RESULT']._serialized_start=2163
  _globals['_CHECKCOMMITINRELEASERESP_RESULT']._serialized_end=2233
  _globals['_RELEASEMANAGER']._serialized_start=2236
  _globals['_RELEASEMANAGER']._serialized_end=3260
# @@protoc_insertion_point(module_scope)
