# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.release import manager_pb2 as prodvana_dot_release_dot_manager__pb2


class ReleaseManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RecordRelease = channel.unary_unary(
                '/prodvana.release.ReleaseManager/RecordRelease',
                request_serializer=prodvana_dot_release_dot_manager__pb2.RecordReleaseReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.RecordReleaseResp.FromString,
                )
        self.UpdateReleaseStatus = channel.unary_unary(
                '/prodvana.release.ReleaseManager/UpdateReleaseStatus',
                request_serializer=prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusResp.FromString,
                )
        self.ListReleases = channel.unary_unary(
                '/prodvana.release.ReleaseManager/ListReleases',
                request_serializer=prodvana_dot_release_dot_manager__pb2.ListReleasesReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.ListReleasesResp.FromString,
                )
        self.ListReleasesStream = channel.unary_stream(
                '/prodvana.release.ReleaseManager/ListReleasesStream',
                request_serializer=prodvana_dot_release_dot_manager__pb2.ListReleasesReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.ListReleasesResp.FromString,
                )
        self.CompareRelease = channel.unary_unary(
                '/prodvana.release.ReleaseManager/CompareRelease',
                request_serializer=prodvana_dot_release_dot_manager__pb2.CompareReleaseReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.CompareReleaseResp.FromString,
                )
        self.PreviewRelease = channel.unary_unary(
                '/prodvana.release.ReleaseManager/PreviewRelease',
                request_serializer=prodvana_dot_release_dot_manager__pb2.PreviewReleaseReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.PreviewReleaseResp.FromString,
                )
        self.GetLatestReleases = channel.unary_unary(
                '/prodvana.release.ReleaseManager/GetLatestReleases',
                request_serializer=prodvana_dot_release_dot_manager__pb2.GetLatestReleasesReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.GetLatestReleasesResp.FromString,
                )
        self.CheckCommitInRelease = channel.unary_unary(
                '/prodvana.release.ReleaseManager/CheckCommitInRelease',
                request_serializer=prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseReq.SerializeToString,
                response_deserializer=prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseResp.FromString,
                )


class ReleaseManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RecordRelease(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateReleaseStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListReleases(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListReleasesStream(self, request, context):
        """page tokens arguments are ignored here
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompareRelease(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviewRelease(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestReleases(self, request, context):
        """returns the latest releases for each (application, service, release channel) tuple.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckCommitInRelease(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReleaseManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RecordRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordRelease,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.RecordReleaseReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.RecordReleaseResp.SerializeToString,
            ),
            'UpdateReleaseStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateReleaseStatus,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusResp.SerializeToString,
            ),
            'ListReleases': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReleases,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.ListReleasesReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.ListReleasesResp.SerializeToString,
            ),
            'ListReleasesStream': grpc.unary_stream_rpc_method_handler(
                    servicer.ListReleasesStream,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.ListReleasesReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.ListReleasesResp.SerializeToString,
            ),
            'CompareRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.CompareRelease,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.CompareReleaseReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.CompareReleaseResp.SerializeToString,
            ),
            'PreviewRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviewRelease,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.PreviewReleaseReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.PreviewReleaseResp.SerializeToString,
            ),
            'GetLatestReleases': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestReleases,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.GetLatestReleasesReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.GetLatestReleasesResp.SerializeToString,
            ),
            'CheckCommitInRelease': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckCommitInRelease,
                    request_deserializer=prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseReq.FromString,
                    response_serializer=prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.release.ReleaseManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ReleaseManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RecordRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/RecordRelease',
            prodvana_dot_release_dot_manager__pb2.RecordReleaseReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.RecordReleaseResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateReleaseStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/UpdateReleaseStatus',
            prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.UpdateReleaseStatusResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListReleases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/ListReleases',
            prodvana_dot_release_dot_manager__pb2.ListReleasesReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.ListReleasesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListReleasesStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/prodvana.release.ReleaseManager/ListReleasesStream',
            prodvana_dot_release_dot_manager__pb2.ListReleasesReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.ListReleasesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompareRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/CompareRelease',
            prodvana_dot_release_dot_manager__pb2.CompareReleaseReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.CompareReleaseResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PreviewRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/PreviewRelease',
            prodvana_dot_release_dot_manager__pb2.PreviewReleaseReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.PreviewReleaseResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestReleases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/GetLatestReleases',
            prodvana_dot_release_dot_manager__pb2.GetLatestReleasesReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.GetLatestReleasesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckCommitInRelease(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.release.ReleaseManager/CheckCommitInRelease',
            prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseReq.SerializeToString,
            prodvana_dot_release_dot_manager__pb2.CheckCommitInReleaseResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
