# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/retry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.prodvana.common_config import notification_pb2 as prodvana_dot_common__config_dot_notification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"prodvana/common_config/retry.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\x1a\x1egoogle/protobuf/duration.proto\x1a)prodvana/common_config/notification.proto\"m\n\x0cNotification\x12\x43\n\x0f\x63onfig_override\x18\x01 \x01(\x0b\x32*.prodvana.common_config.NotificationConfig\x12\x18\n\x07message\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xc1\x01\n\x0bRetryConfig\x12\x41\n\x12max_retry_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00H\x00\x12\x17\n\rretry_forever\x18\x02 \x01(\x08H\x00\x12H\n\x1a\x66irst_failure_notification\x18\x03 \x01(\x0b\x32$.prodvana.common_config.NotificationB\x0c\n\x05limit\x12\x03\xf8\x42\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.retry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _NOTIFICATION.fields_by_name['message']._options = None
  _NOTIFICATION.fields_by_name['message']._serialized_options = b'\372B\004r\002\020\001'
  _RETRYCONFIG.oneofs_by_name['limit']._options = None
  _RETRYCONFIG.oneofs_by_name['limit']._serialized_options = b'\370B\001'
  _RETRYCONFIG.fields_by_name['max_retry_duration']._options = None
  _RETRYCONFIG.fields_by_name['max_retry_duration']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_NOTIFICATION']._serialized_start=162
  _globals['_NOTIFICATION']._serialized_end=271
  _globals['_RETRYCONFIG']._serialized_start=274
  _globals['_RETRYCONFIG']._serialized_end=467
# @@protoc_insertion_point(module_scope)
