"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ImpactCategory:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ImpactCategoryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ImpactCategory.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_CATEGORY: _ImpactCategory.ValueType  # 0
    BACKEND: _ImpactCategory.ValueType  # 1
    FRONTEND: _ImpactCategory.ValueType  # 2
    DATA_INTEGRITY: _ImpactCategory.ValueType  # 3
    SECURITY: _ImpactCategory.ValueType  # 4
    COST: _ImpactCategory.ValueType  # 5
    PRODVANA_INTERNAL_ERROR: _ImpactCategory.ValueType  # 6
    """Prodvana is having trouble determining the impact of this commit"""

class ImpactCategory(_ImpactCategory, metaclass=_ImpactCategoryEnumTypeWrapper): ...

UNKNOWN_CATEGORY: ImpactCategory.ValueType  # 0
BACKEND: ImpactCategory.ValueType  # 1
FRONTEND: ImpactCategory.ValueType  # 2
DATA_INTEGRITY: ImpactCategory.ValueType  # 3
SECURITY: ImpactCategory.ValueType  # 4
COST: ImpactCategory.ValueType  # 5
PRODVANA_INTERNAL_ERROR: ImpactCategory.ValueType  # 6
"""Prodvana is having trouble determining the impact of this commit"""
global___ImpactCategory = ImpactCategory

class _IncidentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IncidentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IncidentType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_INCIDENT: _IncidentType.ValueType  # 0
    OUTAGE: _IncidentType.ValueType  # 1
    EXPENSE: _IncidentType.ValueType  # 2
    SECURITY_BREACH: _IncidentType.ValueType  # 3
    USER_ISSUE: _IncidentType.ValueType  # 4

class IncidentType(_IncidentType, metaclass=_IncidentTypeEnumTypeWrapper): ...

UNKNOWN_INCIDENT: IncidentType.ValueType  # 0
OUTAGE: IncidentType.ValueType  # 1
EXPENSE: IncidentType.ValueType  # 2
SECURITY_BREACH: IncidentType.ValueType  # 3
USER_ISSUE: IncidentType.ValueType  # 4
global___IncidentType = IncidentType

class ImpactAnalysisResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORY_FIELD_NUMBER: builtins.int
    INCIDENT_TYPE_FIELD_NUMBER: builtins.int
    IMPACT_SCORE_FIELD_NUMBER: builtins.int
    IMPACT_REASONING_FIELD_NUMBER: builtins.int
    LIKELIHOOD_SCORE_FIELD_NUMBER: builtins.int
    LIKELIHOOD_REASONING_FIELD_NUMBER: builtins.int
    OVERALL_SCORE_FIELD_NUMBER: builtins.int
    category: global___ImpactCategory.ValueType
    incident_type: global___IncidentType.ValueType
    impact_score: builtins.float
    impact_reasoning: builtins.str
    likelihood_score: builtins.float
    likelihood_reasoning: builtins.str
    overall_score: builtins.float
    def __init__(
        self,
        *,
        category: global___ImpactCategory.ValueType = ...,
        incident_type: global___IncidentType.ValueType = ...,
        impact_score: builtins.float = ...,
        impact_reasoning: builtins.str = ...,
        likelihood_score: builtins.float = ...,
        likelihood_reasoning: builtins.str = ...,
        overall_score: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["category", b"category", "impact_reasoning", b"impact_reasoning", "impact_score", b"impact_score", "incident_type", b"incident_type", "likelihood_reasoning", b"likelihood_reasoning", "likelihood_score", b"likelihood_score", "overall_score", b"overall_score"]) -> None: ...

global___ImpactAnalysisResult = ImpactAnalysisResult
