# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/runtimes/extensions/get_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+prodvana/runtimes/extensions/get_info.proto\x12\x1cprodvana.runtimes.extensions\"M\n\rGetInfoOutput\x12<\n\x07outputs\x18\x01 \x03(\x0b\x32+.prodvana.runtimes.extensions.OutputContent\"+\n\rOutputContent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\tBXZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimes/extensionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.runtimes.extensions.get_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZVgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimes/extensions'
  _globals['_GETINFOOUTPUT']._serialized_start=77
  _globals['_GETINFOOUTPUT']._serialized_end=154
  _globals['_OUTPUTCONTENT']._serialized_start=156
  _globals['_OUTPUTCONTENT']._serialized_end=199
# @@protoc_insertion_point(module_scope)
