# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/runtimes/features.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/runtimes/features.proto\x12\x11prodvana.runtimes*s\n\x0b\x46\x65\x61tureType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0f\x45XPOSED_SERVICE\x10\x01\x12\x0f\n\x0bTLS_SERVICE\x10\x02\x12\x11\n\rCOST_ANALYSIS\x10\x03\x12\x0b\n\x07\x44\x41TADOG\x10\x04\x12\x11\n\rARGO_ROLLOUTS\x10\x05\x42MZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.runtimes.features_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimes'
  _globals['_FEATURETYPE']._serialized_start=55
  _globals['_FEATURETYPE']._serialized_end=170
# @@protoc_insertion_point(module_scope)
